@@ -12,7 +12,7 @@ use base qw(Net::DNS::Resolver::Base DynaLoader), OS_CONF;
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.30_01';
+	$VERSION = '1.30_02';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
@@ -80,7 +80,7 @@ In particular, the queryID returned by Unbound is always zero.
 =back
 
 
-=head1 REPLACING Net::DNS::Resolver BASE CLASS
+=head2 Replacing Net::DNS::Resolver Base Class
 
 Placing C<-register> in the L<Net::DNS::Resolver::Unbound> import list, will
 cause it to register itself with L<Net::DNS> as the resolver base class.
@@ -153,10 +153,6 @@ The domain suffix to be appended to a short non-absolute name.
 
 A space-separated list of domains in the desired search path.
 
-=item B<options> option:value ...
-
-A space-separated list of key:value items.
-
 =back
 
 Except for F</etc/resolv.conf>, files will only be read if owned by the
@@ -663,7 +659,7 @@ sub _finalise_config {
 	my $ctx = $self->{ub_ctx} = Net::DNS::Resolver::Unbound::Context->new();
 	foreach my $name ( keys %option ) {			# set unbound options
 		foreach my $value ( map { ref($_) ? @$_ : $_ } $option{$name} ) {
-			$ctx->set_option( $name, $value );
+			eval { $ctx->set_option( $name, $value ) };
 		}
 	}
 
